import requests
import os

from sieve.api.constants import API_URL, API_BASE
from sieve.api.utils import get_api_key
from pydantic import BaseModel
import base64
import pickle


class JobReference(BaseModel):
    id: str

    def info(self, API_KEY=None):
        return info(self.id, API_KEY=API_KEY)

    def status(self, API_KEY=None):
        return status(self.id, API_KEY=API_KEY)


def get(job_id=None, API_KEY=None, limit=10000, offset=0):
    """
    Get a job by id
    """

    api_key = get_api_key(API_KEY)
    headers = {
        "X-API-Key": api_key,
        "Content-Type": "application/json",
    }
    r = requests.get(
        f"{API_URL}/{API_BASE}/jobs/{job_id}",
        params={"limit": limit, "offset": offset},
        headers=headers,
    )
    rjson = r.json()
    return rjson


def info(job_id=None, API_KEY=None):
    """
    Get information about a specific job
    """

    api_key = get_api_key(API_KEY)
    headers = {
        "X-API-Key": api_key,
        "Content-Type": "application/json",
    }
    r = requests.get(f"{API_URL}/{API_BASE}/jobs/{job_id}/info", headers=headers)
    return r.json()


def list(limit=10000, offset=0, API_KEY=None):
    """
    List all jobs
    """

    api_key = get_api_key(API_KEY)
    headers = {
        "X-API-Key": api_key,
        "Content-Type": "application/json",
    }
    r = requests.get(
        f"{API_URL}/{API_BASE}/jobs",
        params={"limit": limit, "offset": offset},
        headers=headers,
    )
    rjson = r.json()
    return rjson["data"], rjson["next_offset"]


def search(filter_dict, limit=10000, offset=0, API_KEY=None):
    """
    Search for jobs given a filter
    """

    api_key = get_api_key(API_KEY)
    headers = {
        "X-API-Key": api_key,
        "Content-Type": "application/json",
    }
    r = requests.post(
        f"{API_URL}/{API_BASE}/jobs",
        params={"limit": limit, "offset": offset},
        json=filter_dict,
        headers=headers,
    )
    rjson = r.json()
    return rjson["data"], rjson["next_offset"]


def status(job_id=None, API_KEY=None):
    """
    Get the status of a specific job
    """

    api_key = get_api_key(API_KEY)
    headers = {
        "X-API-Key": api_key,
        "Content-Type": "application/json",
    }
    r = requests.get(f"{API_URL}/{API_BASE}/jobs/{job_id}/status", headers=headers)
    return r.json()
